load('.\CuneatePaperData.mat')

%% Figure 1 - Indentation
figure('Name', 'Figure1 - Indentation');
% Indentation raster
bin_width = 0.005;
bin_edges = [-0.3:bin_width:0.8];
bin_x = bin_edges(1:end-1) + (bin_width/2);
psth_height = 20;
ttp = 50; % Trials to plot

subplot(3,2,[1,3,5]); hold on
noi = [1:4];
tick_color = [0.4 0.4 0.4];
t_count = 1;
for n = 1:length(noi)
    for t = 1:ttp
      temp_spikes = data.indentation_data.aligned_spikes{n,t};
      if length(temp_spikes) > 1
        r = rasterfy({temp_spikes}, 0.5);
        plot(r{1,1}, r{1,2}+t_count, 'Color', tick_color, 'LineWidth', 1)
      end
      t_count = t_count + 1;
    end
    
    t_count = t_count + 9;
    
    temp_spikes = horzcat(data.indentation_data.aligned_spikes{n,:});
    temp_hist = smoothdata(histcounts(temp_spikes, bin_edges), 'gaussian', 5);
    temp_hist = rescale(temp_hist, 0, psth_height);
    plot(bin_x, temp_hist + t_count, 'Color', tick_color, 'LineWidth', 1)
    
    t_count = t_count + psth_height + 10;
end

% Scale line
plot([0 0.25], [-2.5,-2.5], 'k', 'LineWidth', 1.5)
text(0.125, -2.6, '250 ms',...
    'VerticalAlignment', 'top', 'HorizontalAlignment', 'center', 'Color', [0.6 0.6 0.6])
set(gca,'YColor', 'w', 'XColor', 'w'); yticks([])
% Stimulus
stim_color = [48,63,159]./255;
yvals = [0 0 1 1 0 0]*psth_height*2 + t_count+10;
plot([-0.3 0 0.025 0.5 0.525 0.8], yvals, 'LineWidth', 1.5, 'Color', stim_color)
text(0.2625, max(yvals), 'Stimulus',...
    'VerticalAlignment', 'top', 'HorizontalAlignment', 'center', 'Color', stim_color)
plot([0.275 0.375], [t_count-psth_height+10,t_count-psth_height+10], 'Color', 'k', 'LineWidth', 1.5)
text(.2625+0.05, t_count-psth_height+10, 'Sus',...
    'VerticalAlignment', 'bottom', 'HorizontalAlignment', 'center', 'Color', [0.6 0.6 0.6])
plot([0.505 0.605], [t_count-psth_height+10,t_count-psth_height+10], 'Color', 'k', 'LineWidth', 1.5)
text(0.555, t_count-psth_height+10, 'Off',...
    'VerticalAlignment', 'bottom', 'HorizontalAlignment', 'center', 'Color', [0.6 0.6 0.6])

ylim([-5 t_count + psth_height*1.5 + 30]); xlim([-0.3 0.8])

% Adaptability Index
bin_edges = linspace(0,1,8);

subplot(3,2,2); hold on
histogram(data.indentation_data.PeripheralAI, bin_edges, 'normalization', 'probability', 'FaceColor', afferent_color)
xticks([]); yticks([]); ylim([0 0.7])
text(0.5, 0.7, 'Afferent', 'VerticalAlignment', 'top', 'HorizontalAlignment', 'center', 'Color', afferent_color)

subplot(3,2,4); hold on
histogram(data.indentation_data.adaptability_index, bin_edges, 'normalization', 'probability', 'FaceColor', cuneate_color)
xticks([]); yticks([]); ylim([0 0.4])
text(0.5, 0.4, 'Cuneate', 'VerticalAlignment', 'top', 'HorizontalAlignment', 'center', 'Color', cuneate_color)
y = ylabel('Proportion'); 

subplot(3,2,6); hold on
histogram(data.indentation_data.CorticalAI, bin_edges, 'normalization', 'probability', 'FaceColor', cortex_color)
text(0.5, 0.25, 'Area 3b', 'VerticalAlignment', 'top', 'HorizontalAlignment', 'center', 'Color', cortex_color)
xticks([0, 1]); yticks([]);
xl = xlabel('Adaptation Index');

%% Figure 2 - Vibratory responses
figure('Name', 'Vibratory Responses');

for n = 1:3
    subplot(2,3,n); hold on
    
    temp_spikes = data.sine_data.spike_times(n,:);
    temp_params = data.sine_data.stim_params{n};
    param_idx = sine_param_sort(temp_params);
    freqs = unique(temp_params(:,1));
    amps = unique(temp_params(:,2));

    t_count = 0;
    for t = 1:size(temp_spikes,2)
      [f,~] = find(freqs == temp_params(param_idx(t),1));
      r = rasterfy(temp_spikes(param_idx(t)), 0.5);
      plot(r{1,1}, r{1,2}+t_count, 'Color', data.sine_data.colorscheme(f,:), 'LineWidth', 1)
      t_count = t_count + 1;
    end
    
    set(gca, 'YDir', 'reverse', 'YLim', [0 t_count*1.01]);
end

for n = 1:3
    subplot(2,3,n+3); hold on
    temp_frs = data.sine_data.fr{n,2};
    temp_params = data.sine_data.stim_params{n};
    for f = 1:length(freqs)
        [y_mean, y_sem, x_a] = deal([]);
        for a = 1:length(amps)
            fr_idx =  find(temp_params(:,1) == freqs(f) & temp_params(:,2) == amps(a));
            if length(fr_idx) > 0
                matching_frs = temp_frs(fr_idx);
                y_mean(1,end+1) = nanmean(matching_frs);
                y_sem(1,end+1) = nanstd(matching_frs) / sqrt(length(fr_idx));
                x_a(1,end+1) = amps(a);
            end
        end

        fill([x_a, fliplr(x_a)],[y_mean+y_sem, fliplr(y_mean-y_sem)], ...
        data. sine_data.colorscheme(f,:), 'EdgeColor', data.sine_data.colorscheme(f,:),'FaceAlpha', 0.1, 'EdgeAlpha', 0)
        plot(x_a, y_mean, 'color', data.sine_data.colorscheme(f,:), 'LineWidth', 1.5, 'LineStyle', '-')
        set(gca, 'XScale', 'log');
    end
end

%% Figure 3 - Sine modelling
fig_size = [7 17];
figure('Name', 'SineModelling');
subplot(3,1,1); hold on
scatter(data.sine_data.aff_mean_regression_r2_best, data.sine_data.aff_mean_regression_r2_all,...
        'MarkerEdgeColor', afferent_color, 'MarkerFaceColor', afferent_color, 'MarkerFaceAlpha', 0.2)
scatter(data.sine_data.mean_regression_r2_best, data.sine_data.mean_regression_r2_all,...
        'MarkerEdgeColor', cuneate_color, 'MarkerFaceColor', cuneate_color, 'MarkerFaceAlpha', 0.2)
    
plot([0 1],[0 1], 'k', 'LineStyle', '--')
xlim([0 1]); ylim([0 1]); xticks([0:0.5:1]); yticks([0:0.5:1])
xlabel('Best Single Afferent Class (R^2)'); ylabel('All Afferent Classes (R^2)')

avb_leg_text = color_legend([{'Cuneate'}, {'Afferents'}], [cuneate_color; afferent_color]);
text(0.05, 1, avb_leg_text, 'VerticalAlignment', 'top', 'HorizontalAlignment', 'left')

axes('Position', [0.7 0.745 0.2 0.1]); hold on
delta_aff = data.sine_data.aff_mean_regression_r2_all - data.sine_data.aff_mean_regression_r2_best;
delta_cun = data.sine_data.mean_regression_r2_all - data.sine_data.mean_regression_r2_best;

bee_swarm(delta_aff, 1, afferent_color, 20, 'none')
plot([0.75 1.25], [mean(delta_aff) mean(delta_aff)], 'Color', 'k', 'LineWidth', 1.5)
bee_swarm(delta_cun, 2, cuneate_color, 20, 'none')
plot([1.75 2.25], [mean(delta_cun) mean(delta_cun)], 'Color', 'k', 'LineWidth', 1.5)
xticks([]); xlim([0.5 2.5]);

subplot(3,1,2); hold on
% Cuneate
all_mean = nanmean(data.sine_data.iterative_r2_all,1);
all_std = nanstd(data.sine_data.iterative_r2_all,[],1) / sqrt(size(data.sine_data.iterative_r2_all,2));
fill([[1:size(data.sine_data.iterative_r2_all,2)], fliplr([1:size(data.sine_data.iterative_r2_all,2)])],...
    [all_mean+all_std, fliplr(all_mean-all_std)], cuneate_color, 'EdgeColor', cuneate_color,...
    'FaceAlpha', 0.1, 'EdgeAlpha', 0)
plot([1:size(data.sine_data.iterative_r2_all,2)], all_mean, 'color', cuneate_color, 'LineWidth', 1.5, 'LineStyle', '-')
    
best_mean = nanmean(data.sine_data.iterative_r2_best,1);
plot([1:size(data.sine_data.iterative_r2_best,2)], best_mean, 'color', cuneate_color, 'LineWidth', 1.5, 'LineStyle', '--')

% Afferent
all_mean = nanmean(data.sine_data.aff_iterative_r2_all,1);
all_std = nanstd(data.sine_data.aff_iterative_r2_all,[],1) / sqrt(size(data.sine_data.aff_iterative_r2_all,2));
fill([[1:size(data.sine_data.aff_iterative_r2_all,2)], fliplr([1:size(data.sine_data.aff_iterative_r2_all,2)])],...
    [all_mean+all_std, fliplr(all_mean-all_std)], afferent_color, 'EdgeColor', afferent_color,...
    'FaceAlpha', 0.1, 'EdgeAlpha', 0)
plot([1:size(data.sine_data.aff_iterative_r2_all,2)], all_mean, 'color', afferent_color, 'LineWidth', 1.5, 'LineStyle', '-')
best_mean = nanmean(data.sine_data.aff_iterative_r2_best,1);
plot([1:size(data.sine_data.aff_iterative_r2_all,2)], best_mean, 'color', afferent_color, 'LineWidth', 1.5, 'LineStyle', '--')

ylabel('R^2'); xlabel('# Afferents')
xlim([0 50]); ylim([0.6 0.95]);
xticks([0:10:50]); yticks([0.6:0.1:0.9])

f3_leg_text = color_legend([{'All Afferents'}, {'Best Afferent Type'}], [cuneate_color; [0.6 0.6 0.6]]);


subplot(3,1,3); hold on
scatter(data.sine_data.normalized_iterative_regression_weights(:,1),...
        data.sine_data.normalized_iterative_regression_weights(:,2),...
        'MarkerEdgeColor', cuneate_color, 'MarkerFaceColor', cuneate_color, 'MarkerFaceAlpha', 0.15)

plot([-1 0 1 -1],[0 1 0 0], 'LineStyle', '--', 'Color', [0.6 0.6 0.6])
plot([-0.5,0],[0.5 0.325], 'LineStyle', '--', 'Color', [0.6 0.6 0.6])
plot([0,0],[0 0.325], 'LineStyle', '--', 'Color', [0.6 0.6 0.6])
plot([0,0.5],[0.325 0.5], 'LineStyle', '--', 'Color', [0.6 0.6 0.6])

set(gca, 'PlotBoxAspectRatio', [1,1,1]);
xlim([-1 1]); ylim([0 1.1]);
text(-1,0, 'SA', 'VerticalAlignment', 'top', 'HorizontalAlignment', 'right')
text(1,0, 'RA', 'VerticalAlignment', 'top', 'HorizontalAlignment', 'left')
text(0,1, 'PC', 'VerticalAlignment', 'bottom', 'HorizontalAlignment', 'center')

%% Figure 4 - Afferent filters

figure('Name', 'Afferent Filters');
fig_size = [17 9];
aff_leg_text = color_legend([{'SA'}, {'RA'}, {'PC'}], [sa_color; ra_color; pc_color]);
cols = [sa_color; ra_color; pc_color];
for i = 1:3
    subplot(2,3,i); hold on
    m = 0;
    for a = 1:3
        temp = data.noise_data.afferent_filters{i,a}*2+a/13;
        base = mean(temp(1:round(length(temp)/2)));
        plot([0 100], [base base] ,'Color', [0.4 .4 .4], 'LineWidth', 1, 'LineStyle', ':')
        plot(temp ,'Color', cols(a,:), 'LineWidth', 1.5)
        if i == 1
           text(-5, mean(data.noise_data.afferent_filters{i,a}*2+a/13), aff_leg_text{a}, 'HorizontalAlignment', 'right')
        end
    end
    
    if i == 1
        plot([50 60], [0.06 0.06], 'Color', [0.6 0.6 0.6], 'LineWidth', 1.5)
        text(55, .055, '10 ms', 'VerticalAlignment', 'top', 'HorizontalAlignment', 'center')
    end
    
    ylim([.05 0.32]); xlim([50 100])
    xticks([0 100]); xticklabels({'-100', '0'});
    h = gca;
    hp = h.Position; hp(4) = hp(4) + 0.05;
    set(gca, 'YColor', 'none', 'XColor', 'none', 'Position', hp)
end


% Filter characteristics
axes('Position', [0.1 0.1 0.275 0.3])
xlim([0.5 3.5])
tm = data.noise_data.filter_mag_positive(:,1) + abs(data.noise_data.filter_mag_negative(:,1));
bee_swarm(tm, 1, [178,223,219]./255, 20, 'none')
plot([0.75 1.25], [mean(tm) mean(tm)], 'Color', sa_color, 'LineWidth', 1.5)

tm = data.noise_data.filter_mag_positive(:,2) + abs(data.noise_data.filter_mag_negative(:,2));
bee_swarm(tm, 2, [197,202,233]./255, 20, 'none')
plot([1.75 2.25], [mean(tm) mean(tm)], 'Color', ra_color, 'LineWidth', 1.5)

tm = data.noise_data.filter_mag_positive(:,3) + abs(data.noise_data.filter_mag_negative(:,3));
bee_swarm(tm, 3, [255,224,178]./255, 20, 'none')
plot([2.75 3.25], [mean(tm) mean(tm)], 'Color', pc_color, 'LineWidth', 1.5)

xticklabels({'SA', 'RA', 'PC'}); ylabel([char(931), ' |p(spike)|'])

axes('Position', [0.45 0.1 0.275 0.3])
xlim([0.5 3.5])
bee_swarm(data.noise_data.filter_mag_prop(:,1), 1, [178,223,219]./255, 20, 'none')
plot([0.75 1.25], [mean(data.noise_data.filter_mag_prop(:,1)) mean(data.noise_data.filter_mag_prop(:,1))],...
    'Color', sa_color, 'LineWidth', 1.5)

bee_swarm(data.noise_data.filter_mag_prop(:,2), 2, [197,202,233]./255, 20, 'none')
plot([1.75 2.25], [mean(data.noise_data.filter_mag_prop(:,2)) mean(data.noise_data.filter_mag_prop(:,2))],...
    'Color', ra_color, 'LineWidth', 1.5)

bee_swarm(data.noise_data.filter_mag_prop(:,3), 3, [255,224,178]./255, 20, 'none')
plot([2.75 3.25], [mean(data.noise_data.filter_mag_prop(:,3)) mean(data.noise_data.filter_mag_prop(:,3))], 'Color',...
    pc_color, 'LineWidth', 1.5)
plot([0.5 3.5], [0.5 0.5], 'Color', [0.6 0.6 0.6], 'LineStyle', '--')

xticklabels({'SA', 'RA', 'PC'}); ylabel('Proportion Excitatory')

axes('Position', [0.8 0.1 0.1 0.3])
bee_swarm(data.noise_data.latency*1000, 1, cuneate_color, 20, 'none')
ylim([0 20]); xlim([0.5 1.5]); xticks([]); ylabel('Latency (ms)')

%% Figure 5 - Receptive Fields
stats_type = 'bs'; % bs or bar
rfoi = [3,22,23,29];
t_rfs = data.random_dot_data.cuneate(4).value;
o_rfs = data.random_dot_data.cuneate(2).value;
cuneate_rfs = {};
i = 1;
for rf = rfoi
    base = imgaussfilt(o_rfs{rf}, 6);
    overlay = t_rfs{rf};
    o_idx = ~isnan(overlay);
    composite = base;
    composite(o_idx) = overlay(o_idx);
    composite = imgaussfilt(composite, 1);
    cuneate_rfs{i} = composite;
    i = i + 1;
end

t_rfs = data.random_dot_data.cortex(4).value;
o_rfs = data.random_dot_data.cortex(2).value;
cortical_rfs = {};
rfoi = [6,17,30,29];
i = 1;
for rf = 1:rfoi
    base = imgaussfilt(o_rfs{rf}, 6);
    overlay = t_rfs{rf};
    o_idx = ~isnan(overlay);
    composite = base;
    composite(o_idx) = overlay(o_idx);
    composite = imgaussfilt(composite, 1);
    cortical_rfs{i} = composite;
    i = i + 1;
end

nxf = 4;
x_pad = 0.05;
x_marg = 0.025;
xlims = [x_pad, 1-x_pad];
x_ws = (x_pad*2) + (x_marg*(nxf-1));
x_res = 1 - x_ws;
x_w = x_res / nxf;
x_pos = [];
for i = 1:nxf
    x_pos(i) = x_pad + (x_w * (i-1)) + (x_marg * (i-1));
end
y1 = 0.7;
y2 = 0.45;
xo = 0.03;
ax_pos = [x_pos(1), y1, x_w, x_w;...
          x_pos(2)-xo, y1, x_w, x_w;...
          x_pos(1), y2, x_w, x_w;...
          x_pos(2)-xo, y2, x_w, x_w;...
          x_pos(3)+xo, y1, x_w, x_w;...
          x_pos(4), y1, x_w, x_w;...
          x_pos(3)+xo, y2, x_w, x_w;...
          x_pos(4), y2, x_w, x_w];
    

figure('Name', 'Receptive Fields');
fig_size = [17 12];

% Example RFs
rf_centers = [78,74; 105,90; 92,110; 60,50];
res = 0.1;
im_size = 50;
k = 1;
for i = [1,2,5,6]
    axes('Position', ax_pos(k,:))
    imagesc(cuneate_rfs{k})
    set(gca, 'PlotBoxAspectRatio', [1 1 1])
    
    xlim([rf_centers(k,1) - im_size, rf_centers(k,1) + im_size])
    ylim([rf_centers(k,2) - im_size, rf_centers(k,2) + im_size])
    xticks([]); yticks([])
    
    if k == 1
       h = gca;
       hp = h.OuterPosition;
       hw = x_w*0.7/10;
       yo = -0.02;
       hs = hp(1)+0.065;
       a = annotation('line', [hs, hs+hw], [hp(2)-yo,hp(2)-yo], 'LineWidth', 2);
    end
    
    k = k + 1;
end

k = 1;
for i = [3,4,7,8]
    axes('Position', ax_pos(k+4,:))
    imagesc(data.random_dot_data.cortex(7).value,data.random_dot_data.cortex(7).value,cortical_rfs{k})
    set(gca, 'PlotBoxAspectRatio', [1 1 1])
    
    xlim([-5 5])
    ylim([-5 5])

    xticks([]); yticks([])
    k = k + 1;
end

% Stats
cun_rf_stats = data.random_dot_data.cuneate(3).value;
cor_rf_stats = data.random_dot_data.cortex(3).value;

subplot(3,4,[9,10]); hold on
bee_swarm(cun_rf_stats(:,1), 1, [0.6 0.6 0.6], 20, 'none')
plot([0.75 1.25], [mean(cun_rf_stats(:,1)) mean(cun_rf_stats(:,1))], 'Color', [0.2 0.2 0.2], 'LineWidth', 1.5)
bee_swarm(cun_rf_stats(:,2), 2, [255,202,40]./255, 20, 'none')
plot([1.75 2.25], [mean(cun_rf_stats(:,2)) mean(cun_rf_stats(:,2))], 'Color', [251,192,45]./255, 'LineWidth', 1.5)
bee_swarm(cun_rf_stats(:,3), 3, [92,107,192]./255, 20, 'none')
plot([2.75 3.25], [mean(cun_rf_stats(:,3)) mean(cun_rf_stats(:,3))], 'Color', [48,63,159]./255, 'LineWidth', 1.5)
bee_swarm(data.random_dot_data.gauss_sf_cun, 4, [174,213,129]./255, 20, 'none')
plot([3.75 4.25], [mean(data.random_dot_data.gauss_sf_cun) mean(data.random_dot_data.gauss_sf_cun)], 'Color', [124,179,66]./255, 'LineWidth', 1.5)

xticks([1:4]); xticklabels({'Total', 'Excitatory', 'Inhibitory', '# Subfields'}); 
xlim([0.5 4.5]); ylim([0 15])
ylabel('Size (mm^2)')
h = gca;
h.Position(1) = h.Position(1) - 0.05;

subplot(3,4,[11,12]); hold on
bee_swarm(cor_rf_stats(:,1), 1, [0.6 0.6 0.6], 20, 'none')
plot([0.75 1.25], [mean(cor_rf_stats(:,1)) mean(cor_rf_stats(:,1))], 'Color', [0.2 0.2 0.2], 'LineWidth', 1.5)
bee_swarm(cor_rf_stats(:,2), 2, [255,202,40]./255, 20, 'none')
plot([1.75 2.25], [mean(cor_rf_stats(:,2)) mean(cor_rf_stats(:,2))], 'Color', [251,192,45]./255, 'LineWidth', 1.5)
bee_swarm(cor_rf_stats(:,3), 3, [92,107,192]./255, 20, 'none')
plot([2.75 3.25], [mean(cor_rf_stats(:,3)) mean(cor_rf_stats(:,3))], 'Color', [48,63,159]./255, 'LineWidth', 1.5)
bee_swarm(data.random_dot_data.gauss_sf_cor, 4, [174,213,129]./255, 20, 'none')
plot([3.75 4.25], [mean(data.random_dot_data.gauss_sf_cor) mean(data.random_dot_data.gauss_sf_cor)], 'Color', [124,179,66]./255, 'LineWidth', 1.5)

xticks([1:4]); xticklabels({'Total', 'Excitatory', 'Inhibitory', '# Subfields'}); 
xlim([0.5 4.5]); ylim([0 15])

%% Figure 6 - Orientation Tuning
figure('Name', 'Orientation Tuning');
orientation_frs = data.orientation_data(2).value;
stim_theta = data.orientation_data(1).value;
rpt = 6;
theta_x = [stim_theta; stim_theta(1)];
theta_ticks = [0:45:315] ./ 180 .* pi;
theta_labels = [0:90:270] ./ 180 .* pi;
rho_lims = 0.9;

i = [1,2,4,5];
for n = [1:4]
    subplot(2,3,i(n)); hold on
    temp_frs = squeeze(orientation_frs(:,:,n));
    % Plot mean circular
    mean_fr = repmat(mean(temp_frs,'all'), [1, 100]);
    t = linspace(0, 2*pi, 100);
    [x, y] = pol2cart(t, mean_fr);
    plot(x, y, 'LineStyle', '--', 'Color', [0.6 0.6 0.6])

    % Plot actual
    temp_mean = mean(temp_frs,2);
    temp_mean = [temp_mean; temp_mean(1)];
    temp_std = std(temp_frs, 1, 2) / sqrt(rpt);
    temp_std = [temp_std; temp_std(1)];

    rho_max = max(temp_mean + temp_std);
    rho_tick = ceil(rho_max/5)*5;
    if n == 1
        cartesian_polar_plot(theta_x, temp_mean', temp_std', theta_ticks,...
            rho_tick, [], rho_tick, [0.2 0.2 0.2])
    else
        cartesian_polar_plot(theta_x, temp_mean', temp_std', theta_ticks,...
            rho_tick, [], rho_tick, [0.2 0.2 0.2])
    end

    xlim([-rho_tick*rho_lims, rho_tick*rho_lims]); ylim([-rho_tick*rho_lims, rho_tick*rho_lims])

    pt = theta_ticks(end) + theta_ticks(2)/2;
    [x, y] = pol2cart(pt, rho_tick*1.1);
    text(x,y, ['vs = ', num2str(round(data.orientation_data(3).value(n),2))])
    
    h = gca;
    h.Position(2) = h.Position(2) - 0.05;
    h.Position(1) = h.Position(1) - 0.1;
    h.Clipping = 0;
end

subplot(2,3,[3,6]); hold on
hist_bins = [0:0.025:1];
hist_x = hist_bins(1:end-1) + hist_bins(2)/2;

vs_hist = histcounts(data.orientation_data(3).value, hist_bins);
vs_cumsum = cumsum(vs_hist);
vs_cumprob = vs_cumsum / max(vs_cumsum);
max_idx = find(vs_cumprob == 1); max_idx = max_idx(1);
vs_x = hist_x(1:max_idx);
vs_cumprob = vs_cumprob(1:max_idx);

cortex_vs_hist = histcounts(data.orientation_data(5).value, hist_bins);
cortex_vs_cumsum = cumsum(cortex_vs_hist); cortex_vs_cumsum = cortex_vs_cumsum ./ max(cortex_vs_cumsum);
max_idx = find(cortex_vs_cumsum == 1); max_idx = max_idx(1);
cor_x = hist_x(1:max_idx);
cortex_vs_cumsum = cortex_vs_cumsum(1:max_idx);

aff_vs_hist = histcounts(data.orientation_data(4).value, hist_bins);
aff_vs_cumsum = cumsum(aff_vs_hist); aff_vs_cumsum = aff_vs_cumsum ./ max(aff_vs_cumsum);
max_idx = find(aff_vs_cumsum == 1); max_idx = max_idx(1);
aff_x = hist_x(1:max_idx);
aff_vs_cumsum = aff_vs_cumsum(1:max_idx);

plot(cor_x, cortex_vs_cumsum, 'Color', cortex_color, 'LineWidth', 1.5)
plot(aff_x, aff_vs_cumsum, 'Color', afferent_color, 'LineWidth', 1.5)
plot(vs_x, vs_cumprob, 'Color', cuneate_color, 'LineWidth', 2)

xlabel('Vector Strength'); ylabel('Cumulative Fraction')
xlim([0 0.75]); xticks([0:0.25:0.75])

vs_leg_text = color_legend({'Afferent', 'Cuneate', 'Area 3b'}, [afferent_color;cuneate_color;cortex_color]);
text(0.75,0.2,vs_leg_text, 'HorizontalAlignment', 'right')
