function bee_swarm(group_data, x, group_color, point_size, av_method)
    hold on
    s = 0.3;

    if strcmp(av_method, 'median')
        group_mean = nanmedian(group_data, 'all');
    elseif strcmp(av_method, 'mean')
        group_mean = nanmean(group_data, 'all');
    end
    
    group_data = group_data(~isnan(group_data));
    
    [group_data,~] = sort(group_data);
    
    % Get bins for x-distribution
    [hist_count, ~, ~] = histcounts(group_data(:), 'BinMethod', 'sturges');
    group_hist_prop = (hist_count ./ max(hist_count)) * s;
    
    % Generate random x-values within each bin
    x_vals = [];
    for b = 1:length(hist_count)
        bin_x_vals = linspace(-group_hist_prop(b), group_hist_prop(b), hist_count(b));
        perm_idx = randperm(length(bin_x_vals));
        bin_x_vals = bin_x_vals(perm_idx);
        x_vals = [x_vals; bin_x_vals'];
    end
    
    scatter(x_vals+x, group_data, point_size, 'MarkerFaceColor', group_color, 'MarkerEdgeColor', group_color,'MarkerFaceAlpha', 0.2);
    if strcmp(av_method, 'none') == 0
        plot([x-s, x+s], [group_mean, group_mean], 'Color' , [0.2 0.2 0.2], 'LineWidth', 2)
    end
end