function cartesian_polar_plot(theta, rho_mean, rho_std, theta_ticks, rho_ticks, theta_labels, rho_labels, colorscheme)
    % Setup the axes
    hold on
    h = gca;
    set(h, 'XColor', 'none', 'YColor', 'none', 'clipping', 'off', 'box', 'off',...
        'PlotBoxAspectRatio', [1, 1, 1])
    
    if size(theta,2) == 1 & size(theta,1) > 1
        theta = theta';
    end
    
    % Check Ticks
    if isempty(theta_ticks)
        theta_ticks = [0:30:330] ./ 180 .* pi;
        theta_labels = theta_ticks;
    end
    
    rho_max = rho_mean + rho_std;
    rho_max = ceil(max(rho_max,[], 'all'))*1.1;
        
    autogen_rho_labels = 0;
    if isempty(rho_ticks)
        rho_ticks = [0, ceil(rho_max)];
        rho_labels = rho_ticks(2:end);
        autogen_rho_labels = 1;
    end
    
    if max(rho_labels) > rho_max
        rho_max = max(rho_labels) * 1.1;
    end
    
    xlim([-rho_max*1.5, rho_max*1.5]); ylim([-rho_max*1.5, rho_max*1.5])
    
    % Theta ticks
    [x, y] = pol2cart(theta_ticks, repmat(rho_max*1.1, [1, length(theta_ticks)]));
    for i = 1:length(theta_ticks)
       plot([0,x(i)], [0, y(i)], 'Color', [0.8 0.8 0.8], 'LineWidth', 0.1)
    end
    
    % Theta labels
    if isempty(theta_labels) == 0
        [x, y] = pol2cart(theta_labels, repmat(rho_max*1.25, [1, length(theta_labels)]));
        for t = 1:length(theta_labels)
            text(x(t),y(t), [num2str(rad2deg(theta_labels(t))), char(176)],...
                'VerticalAlignment', 'middle', 'HorizontalAlignment', 'center')
        end
    end
    
    % Rho ticks
    t = linspace(0, 2*pi, 100);
    for r = rho_ticks
        [x, y] = pol2cart(t, repmat(r, [1, 100]));
        plot(x, y, 'Color', [0.8 0.8 0.8], 'LineWidth', 0.1)
    end
    
    % Rho labels
    rt = theta_ticks(2) / 2;
    ro = rho_max * 0.05;
    if isempty(rho_labels) == 0
        [x, y] = pol2cart(repmat(rt, [1,length(rho_labels)]), rho_labels+ro);
        for t = 1:length(rho_labels)
            if t < length(rho_labels)
                text(x(t),y(t), num2str(rho_labels(t)),...
                    'VerticalAlignment', 'middle', 'HorizontalAlignment', 'left')
            else
                text(x(t),y(t), [num2str(rho_labels(t)), ' Hz'],...
                    'VerticalAlignment', 'middle', 'HorizontalAlignment', 'left')
            end
        end
    end
    
    % Check if theta is consistent across Rhos
    if size(theta,1) == 1 &  size(rho_mean,1) > 1
        theta = repmat(theta, [size(rho_mean,1),1]);
    end
    
    % Plot data
    num_lines = size(theta,1);
    for l = 1:num_lines
        rho_outer = rho_mean(l,:) + rho_std(l,:);
        rho_inner = rho_mean(l,:) - rho_std(l,:);
        
        [x, y] = pol2cart(theta(l,:), rho_outer);
        [x2, y2] = pol2cart(theta(l,:), rho_inner);
        fill([x, fliplr(x2)],[y, fliplr(y2)], colorscheme(l,:),...
            'EdgeColor', colorscheme(l,:),'FaceAlpha', 0.1, 'EdgeAlpha', 0)
        [x3, y3] = pol2cart(theta(l,:), rho_mean(l,:));
        plot(x3,y3, 'Color', colorscheme(l,:), 'LineWidth', 1)
    end
end